Documentation
¶
Index ¶
- Variables
- type Matrix2D
- func (a Matrix2D) Invert() Matrix2D
- func (a Matrix2D) Mult(b Matrix2D) Matrix2D
- func (a Matrix2D) Rotate(theta float64) Matrix2D
- func (a Matrix2D) Scale(x, y float64) Matrix2D
- func (a Matrix2D) SkewX(theta float64) Matrix2D
- func (a Matrix2D) SkewY(theta float64) Matrix2D
- func (a Matrix2D) TFixed(x fixed.Point26_6) (y fixed.Point26_6)
- func (a Matrix2D) Transform(x1, y1 float64) (x2, y2 float64)
- func (a Matrix2D) TransformVector(x1, y1 float64) (x2, y2 float64)
- func (a Matrix2D) Translate(x, y float64) Matrix2D
Constants ¶
This section is empty.
Variables ¶
var Identity = Matrix2D{1, 0, 0, 1, 0, 0}
Identity is the identity matrix
Functions ¶
This section is empty.
Types ¶
type Matrix2D ¶
type Matrix2D struct {
A, B, C, D, E, F float64
}
Matrix2D represents an SVG style matrix
func (Matrix2D) Transform ¶
Transform multiples the input vector by matrix m and outputs the results vector components.
func (Matrix2D) TransformVector ¶
TransformVector is a modidifed version of Transform that ignores the translation components.
Click to show internal directories.
Click to hide internal directories.